from enum import Enum, unique

from .background_color import BgColor
from .color import Color


@unique
class BgBrightColor(Enum):
    """Options for bright background colors."""

    GREEN = "\033[102m"
    YELLOW = "\033[103m"
    RED = "\033[101m"
    MAGENTA = "\033[105m"
    BLUE = "\033[104m"
    CYAN = "\033[106m"
    WHITE = "\033[107m"
    BLACK = "\033[100m"
    DEFAULT = BgColor.DEFAULT
    OFF = Color.OFF

    def __str__(self) -> str:
        return str(self.value)



from ..model.background_bright_color import BgBrightColor
from ..model.background_color import BgColor
from ..model.bright_color import BrightColor
from ..model.color import Color
from ..model.effect import Effect


def color(text: str, color: Color | BrightColor | str = "", bgcolor: BgColor | BgBrightColor | str = "") -> None:
    print(f"{bgcolor}{color}{text}{Color.OFF}")


def effect(text: str, effect: Effect, color: Color | BrightColor = Color.DEFAULT) -> None:
    print(f"{color}{effect}{text}{Effect.OFF}")



from . import helper
from .model.background_bright_color import BgBrightColor
from .model.background_color import BgColor
from .model.bright_color import BrightColor
from .model.color import Color
from .model.effect import Effect


def green(text: str) -> None:
    helper.print.color(text, color=Color.GREEN)


def yellow(text: str) -> None:
    helper.print.color(text, color=Color.YELLOW)


def red(text: str) -> None:
    helper.print.color(text, color=Color.RED)


def magenta(text: str) -> None:
    helper.print.color(text, color=Color.MAGENTA)


def blue(text: str) -> None:
    helper.print.color(text, color=Color.BLUE)


def cyan(text: str) -> None:
    helper.print.color(text, color=Color.CYAN)


def white(text: str) -> None:
    helper.print.color(text, color=Color.WHITE)


def black(text: str) -> None:
    helper.print.color(text, color=Color.BLACK)


def bright_green(text: str) -> None:
    helper.print.color(text, color=BrightColor.GREEN)


def bright_yellow(text: str) -> None:
    helper.print.color(text, color=BrightColor.YELLOW)


def bright_red(text: str) -> None:
    helper.print.color(text, color=BrightColor.RED)


def bright_magenta(text: str) -> None:
    helper.print.color(text, color=BrightColor.MAGENTA)


def bright_blue(text: str) -> None:
    helper.print.color(text, color=BrightColor.BLUE)


def bright_cyan(text: str) -> None:
    helper.print.color(text, color=BrightColor.CYAN)


def bright_white(text: str) -> None:
    helper.print.color(text, color=BrightColor.WHITE)


def bright_black(text: str) -> None:
    helper.print.color(text, color=BrightColor.BLACK)


def bg_green(text: str) -> None:
    helper.print.color(text, bgcolor=BgColor.GREEN)


def bg_yellow(text: str) -> None:
    helper.print.color(text, bgcolor=BgColor.YELLOW)


def bg_red(text: str) -> None:
    helper.print.color(text, bgcolor=BgColor.RED)


def bg_magenta(text: str) -> None:
    helper.print.color(text, bgcolor=BgColor.MAGENTA)


def bg_blue(text: str) -> None:
    helper.print.color(text, bgcolor=BgColor.BLUE)


def bg_cyan(text: str) -> None:
    helper.print.color(text, bgcolor=BgColor.CYAN)


def bg_white(text: str) -> None:
    helper.print.color(text, bgcolor=BgColor.WHITE)


def bg_black(text: str) -> None:
    helper.print.color(text, bgcolor=BgColor.BLACK)


def bg_bright_green(text: str) -> None:
    helper.print.color(text, bgcolor=BgBrightColor.GREEN)


def bg_bright_yellow(text: str) -> None:
    helper.print.color(text, bgcolor=BgBrightColor.YELLOW)


def bg_bright_red(text: str) -> None:
    helper.print.color(text, bgcolor=BgBrightColor.RED)


def bg_bright_magenta(text: str) -> None:
    helper.print.color(text, bgcolor=BgBrightColor.MAGENTA)


def bg_bright_blue(text: str) -> None:
    helper.print.color(text, bgcolor=BgBrightColor.BLUE)


def bg_bright_cyan(text: str) -> None:
    helper.print.color(text, bgcolor=BgBrightColor.CYAN)


def bg_bright_white(text: str) -> None:
    helper.print.color(text, bgcolor=BgBrightColor.WHITE)


def bg_bright_black(text: str) -> None:
    helper.print.color(text, bgcolor=BgBrightColor.BLACK)


def effect_bold(text: str, color: Color | BrightColor = Color.DEFAULT) -> None:
    helper.print.effect(text, Effect.BOLD, color)


def effect_dim(text: str, color: Color | BrightColor = Color.DEFAULT) -> None:
    helper.print.effect(text, Effect.DIM, color)


def effect_underline(text: str, color: Color | BrightColor = Color.DEFAULT) -> None:
    helper.print.effect(text, Effect.UNDERLINE, color)


def effect_blink(text: str, color: Color | BrightColor = Color.DEFAULT) -> None:
    helper.print.effect(text, Effect.BLINK, color)


def effect_reverse(text: str, color: Color | BrightColor = Color.DEFAULT) -> None:
    helper.print.effect(text, Effect.REVERSE, color)


def effect_hide(text: str, color: Color | BrightColor = Color.DEFAULT) -> None:
    helper.print.effect(text, Effect.HIDE, color)



from enum import Enum, unique

from .color import Color


@unique
class Effect(Enum):
    """Options for effects and styling."""

    BOLD = "\033[1m"
    DIM = "\033[2m"
    UNDERLINE = "\033[4m"
    BLINK = "\033[5m"
    REVERSE = "\033[7m"
    HIDE = "\033[8m"

    BOLD_OFF = "\033[21m"
    DIM_OFF = "\033[22m"
    UNDERLINE_OFF = "\033[24m"
    BLINK_OFF = "\033[25m"
    REVERSE_OFF = "\033[27m"
    HIDE_OFF = "\033[28m"
    OFF = Color.OFF

    def __str__(self) -> str:
        return str(self.value)



__all__ = [  # isort:skip
    "Color", "BrightColor", "BgColor", "BgBrightColor", "Effect",
    "green", "yellow", "red", "magenta", "blue", "cyan", "white", "black",
    "bright_green", "bright_yellow", "bright_red", "bright_magenta", "bright_blue", "bright_cyan", "bright_white", "bright_black",
    "bg_green", "bg_yellow", "bg_red", "bg_magenta", "bg_blue", "bg_cyan", "bg_white", "bg_black",
    "bg_bright_green", "bg_bright_yellow", "bg_bright_red", "bg_bright_magenta", "bg_bright_blue", "bg_bright_cyan", "bg_bright_white", "bg_bright_black",
    "effect_bold", "effect_dim", "effect_underline", "effect_blink", "effect_reverse", "effect_hide"
]

from .model.background_bright_color import BgBrightColor
from .model.background_color import BgColor
from .model.bright_color import BrightColor
from .model.color import Color
from .model.effect import Effect
from .version import __version__  # noqa

from .__main__ import (  # isort:skip
    green, yellow, red, magenta, blue, cyan, white, black,
    bright_green, bright_yellow, bright_red, bright_magenta, bright_blue, bright_cyan, bright_white, bright_black,
    bg_green, bg_yellow, bg_red, bg_magenta, bg_blue, bg_cyan, bg_white, bg_black,
    bg_bright_green, bg_bright_yellow, bg_bright_red, bg_bright_magenta, bg_bright_blue, bg_bright_cyan, bg_bright_white, bg_bright_black,
    effect_bold, effect_dim, effect_underline, effect_blink, effect_reverse, effect_hide
)



from enum import Enum, unique

from .color import Color


@unique
class BrightColor(Enum):
    """Options for bright colors."""

    GREEN = "\033[92m"
    YELLOW = "\033[93m"
    RED = "\033[91m"
    MAGENTA = "\033[95m"
    BLUE = "\033[94m"
    CYAN = "\033[96m"
    WHITE = "\033[97m"
    BLACK = "\033[90m"
    DEFAULT = Color.DEFAULT
    OFF = Color.OFF

    def __str__(self) -> str:
        return str(self.value)
